Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(839)

Unified Diff: ui/display/display.h

Issue 2950183002: color: Use ICCProfile from display::Display instead of FromBestMonitor (Closed)
Patch Set: Use forced color profile in display::Display ctor Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/compositor/compositor.cc ('k') | ui/display/display.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/display/display.h
diff --git a/ui/display/display.h b/ui/display/display.h
index 2f30a59ec4068a7ebd82547d7c233ceb8bf2dae4..f5c928993594daab5598ae67461d07aeed8b51b4 100644
--- a/ui/display/display.h
+++ b/ui/display/display.h
@@ -11,8 +11,8 @@
#include "mojo/public/cpp/bindings/struct_traits.h"
#include "ui/display/display_export.h"
#include "ui/display/types/display_constants.h"
+#include "ui/gfx/color_space.h"
#include "ui/gfx/geometry/rect.h"
-#include "ui/gfx/icc_profile.h"
namespace display {
@@ -184,10 +184,10 @@ class DISPLAY_EXPORT Display final {
maximum_cursor_size_ = size;
}
- // The full ICC profile of the display.
- gfx::ICCProfile icc_profile() const { return icc_profile_; }
- void set_icc_profile(const gfx::ICCProfile& icc_profile) {
- icc_profile_ = icc_profile;
+ // The full color space of the display.
+ gfx::ColorSpace color_space() const { return color_space_; }
+ void set_color_space(const gfx::ColorSpace& color_space) {
+ color_space_ = color_space;
}
// The number of bits per pixel. Used by media query APIs.
@@ -226,7 +226,7 @@ class DISPLAY_EXPORT Display final {
gfx::Size maximum_cursor_size_;
// NOTE: this is not currently written to the mojom as it is not used in
// aura.
- gfx::ICCProfile icc_profile_;
+ gfx::ColorSpace color_space_;
int color_depth_;
int depth_per_component_;
bool is_monochrome_ = false;
« no previous file with comments | « ui/compositor/compositor.cc ('k') | ui/display/display.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698